import requests
from flask import request, jsonify
from flask_restx import Resource, Namespace, reqparse

from app.defines import StatesCode
from app.utils.jwt_util import login_required
from config import Config

ns = Namespace('index', description='指标配置')

config = Config()

index_list = reqparse.RequestParser(bundle_errors=True)
index_list.add_argument(name='page_size', type=int, location='args', required=False, help='每页记录数量，默认:20')
index_list.add_argument(name='page', type=int, location='args', required=False, help='第几页')
index_list.add_argument(name='parent_id', type=int, location='args', required=False, help='父id')


@ns.route('index_list')
class IndexApi(Resource):
    #method_decorators = [login_required]

    @ns.doc(description='获取指标配置列表')
    @ns.expect(index_list)
    def get(self):
        parent_id = int(request.args.get('parent_id'))
        page_size = int(request.args.get('page_size', 20))
        page = int(request.args.get('page', 1))
        params = {
            'parentId': parent_id,
            'page': page,
            'pageSize': page_size
        }
        rep = requests.get(
            'http://{host}:{post}/ioc-api/system_index/getIndexList'.format(host=config.system_monitoring.HOST,
                                                                            post=config.system_monitoring.POST
                                                                            ),
            params=params, headers={'clientId': "99"}).json()

        return jsonify(code=StatesCode.SUCCESS, message='成功', data=rep)
