from sqlalchemy import String, Column, Integer, DateTime, JSON

from app.modle import Base
from app.utils.util import cn_now


class FloorConfiguration(Base):
    """楼层表地图信息配置"""

    __tablename__ = 'FloorConfiguration'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=False, unique=False, index=False, doc='配置名称')
    location = Column(String, nullable=True, unique=False, index=False, doc='楼层位置')
    use = Column(String, nullable=True, unique=False, index=False, doc='楼层用途')
    remark = Column(String, nullable=True, unique=False, index=False, doc='备注')
    attachment = Column(String, nullable=True, unique=False, index=False, doc='附件')
    account = Column(String, nullable=True, unique=False, index=False, doc='上传账户')
    time = Column(String, nullable=True, unique=False, index=False, default=cn_now(), doc='上传时间')


class FloorConfigurationHistory(Base):
    """楼层表地图信息配置历史记录"""

    __tablename__ = 'FloorConfigurationHistory'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    floor_configuration = Column(Integer, nullable=False, unique=False, index=False, doc='楼层表地图信息配置id')
    url = Column(String, nullable=False, unique=False, index=False, default={}, doc='图片url列表')


class StaffConfiguration(Base):
    """安保人员信息配置"""

    __tablename__ = 'StaffConfiguration'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=False, unique=False, index=False, doc='配置名称')
    personnel_type = Column(String, nullable=True, unique=False, index=False, doc='人员类别')
    responsibility_range = Column(String, nullable=True, unique=False, index=False, doc='职责范围')
    staff_list = Column(String, nullable=True, unique=False, index=False, doc='人员名单')
    remark = Column(String, nullable=True, unique=False, index=False, doc='备注')
    duty_time = Column(JSON, nullable=True, unique=False, index=False, doc="值班日期：{'start_time': '', end_time: ''}")


class SecurityPerson(Base):
    """人员表"""

    __tablename__ = 'security_person'

    id = Column(Integer, primary_key=True, autoincrement=True, nullable=False, unique=True, doc='id')
    name = Column(String, nullable=True, unique=False, index=False, doc='姓名')
    work_number = Column(String, nullable=True, unique=False, index=False, doc='工号')
    phone = Column(String, nullable=True, unique=False, index=False, doc='联系电话')
    scope = Column(String, nullable=True, unique=False, index=False, doc='工作区域')
    company_id = Column(Integer, nullable=True, unique=False, index=False, doc='单位id')
    dept_id = Column(Integer, nullable=True, unique=False, index=False, doc='部门id')
    company = Column(String, nullable=True, unique=False, index=False, doc='单位')
    department = Column(String, nullable=True, unique=False, index=False, doc='部门')
    register_time = Column(String, nullable=True, unique=False, index=False, doc='入职时间')
    type = Column(Integer, nullable=True, unique=False, index=False, doc='人员类型 1安防人员 2前台人员')
    photo = Column(String, nullable=True, unique=False, index=False, doc='头像')
